@@ -63,8 +63,12 @@ class ConnectionServiceAsyncClient:
     DEFAULT_ENDPOINT = ConnectionServiceClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = ConnectionServiceClient.DEFAULT_MTLS_ENDPOINT
 
+    cluster_path = staticmethod(ConnectionServiceClient.cluster_path)
+    parse_cluster_path = staticmethod(ConnectionServiceClient.parse_cluster_path)
     connection_path = staticmethod(ConnectionServiceClient.connection_path)
     parse_connection_path = staticmethod(ConnectionServiceClient.parse_connection_path)
+    service_path = staticmethod(ConnectionServiceClient.service_path)
+    parse_service_path = staticmethod(ConnectionServiceClient.parse_service_path)
     common_billing_account_path = staticmethod(
         ConnectionServiceClient.common_billing_account_path
     )
@@ -846,8 +850,7 @@ class ConnectionServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.iam.v1.iam_policy_pb2.GetIamPolicyRequest, dict]]):
-                The request object. Request message for `GetIamPolicy`
-                method.
+                The request object. Request message for ``GetIamPolicy`` method.
             resource (:class:`str`):
                 REQUIRED: The resource for which the
                 policy is being requested. See the
@@ -1016,8 +1019,7 @@ class ConnectionServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.iam.v1.iam_policy_pb2.SetIamPolicyRequest, dict]]):
-                The request object. Request message for `SetIamPolicy`
-                method.
+                The request object. Request message for ``SetIamPolicy`` method.
             resource (:class:`str`):
                 REQUIRED: The resource for which the
                 policy is being specified. See the
@@ -1191,8 +1193,7 @@ class ConnectionServiceAsyncClient:
 
         Args:
             request (Optional[Union[google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest, dict]]):
-                The request object. Request message for
-                `TestIamPermissions` method.
+                The request object. Request message for ``TestIamPermissions`` method.
             resource (:class:`str`):
                 REQUIRED: The resource for which the
                 policy detail is being requested. See
