@@ -428,7 +428,6 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                 request (~.gcbc_connection.CreateConnectionRequest):
                     The request object. The request for
                 [ConnectionService.CreateConnection][google.cloud.bigquery.connection.v1.ConnectionService.CreateConnection].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -530,7 +529,6 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                 request (~.connection.DeleteConnectionRequest):
                     The request object. The request for
                 [ConnectionService.DeleteConnectionRequest][].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -608,7 +606,6 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                 request (~.connection.GetConnectionRequest):
                     The request object. The request for
                 [ConnectionService.GetConnection][google.cloud.bigquery.connection.v1.ConnectionService.GetConnection].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -749,7 +746,8 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                           "condition": {
                             "title": "expirable access",
                             "description": "Does not grant access after Sep 2020",
-                            "expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')",
+                            "expression": "request.time <
+                            timestamp('2020-10-01T00:00:00.000Z')",
                           }
                         }
                       ],
@@ -870,7 +868,6 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                 request (~.connection.ListConnectionsRequest):
                     The request object. The request for
                 [ConnectionService.ListConnections][google.cloud.bigquery.connection.v1.ConnectionService.ListConnections].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
@@ -1012,7 +1009,8 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                           "condition": {
                             "title": "expirable access",
                             "description": "Does not grant access after Sep 2020",
-                            "expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')",
+                            "expression": "request.time <
+                            timestamp('2020-10-01T00:00:00.000Z')",
                           }
                         }
                       ],
@@ -1230,7 +1228,6 @@ class ConnectionServiceRestTransport(ConnectionServiceTransport):
                 request (~.gcbc_connection.UpdateConnectionRequest):
                     The request object. The request for
                 [ConnectionService.UpdateConnection][google.cloud.bigquery.connection.v1.ConnectionService.UpdateConnection].
-
                 retry (google.api_core.retry.Retry): Designation of what errors, if any,
                     should be retried.
                 timeout (float): The timeout for this request.
