@@ -28,6 +28,9 @@ from .connection import (
     GetConnectionRequest,
     ListConnectionsRequest,
     ListConnectionsResponse,
+    MetastoreServiceConfig,
+    SparkHistoryServerConfig,
+    SparkProperties,
     UpdateConnectionRequest,
 )
 
@@ -46,5 +49,8 @@ __all__ = (
     "GetConnectionRequest",
     "ListConnectionsRequest",
     "ListConnectionsResponse",
+    "MetastoreServiceConfig",
+    "SparkHistoryServerConfig",
+    "SparkProperties",
     "UpdateConnectionRequest",
 )
